@@ -188,7 +188,7 @@ def _prepare_asset_details_params(**options):
 
     :internal
     """
-    return only(options, "exif", "faces", "colors", "image_metadata", "cinemagraph_analysis",
+    return only(options, "exif", "faces", "colors", "image_metadata", "media_metadata", "cinemagraph_analysis",
                 "pages", "phash", "coordinates", "max_results", "quality_analysis", "derived_next_cursor",
                 "accessibility_analysis", "versions")
 
@@ -223,6 +223,8 @@ def update(public_id, **options):
         params["display_name"] = options.get("display_name")
     if "unique_display_name" in options:
         params["unique_display_name"] = options.get("unique_display_name")
+    if "clear_invalid" in options:
+        params["clear_invalid"] = options.get("clear_invalid")
 
     return call_api("post", uri, params, **options)
 
