@@ -288,13 +288,14 @@ class ApiTest(unittest.TestCase):
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test07_a_resource_by_asset_id(self, mocker):
         mocker.return_value = MOCK_RESPONSE
-        api.resource_by_asset_id(API_TEST_ID, quality_analysis=True , colors=True ,accessibility_analysis=True)
+        api.resource_by_asset_id(API_TEST_ID, quality_analysis=True, colors=True, accessibility_analysis=True,
+                                 media_metadata=True)
         args, kargs = mocker.call_args
         self.assertTrue(get_uri(args).endswith('/resources/{}'.format(API_TEST_ID)))
         self.assertTrue(get_params(args)['quality_analysis'])
         self.assertTrue(get_params(args)['colors'])
         self.assertTrue(get_params(args)['accessibility_analysis'])
-
+        self.assertTrue(get_params(args)['media_metadata'])
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test07_b_resource_by_asset_id(self):
@@ -812,6 +813,13 @@ class ApiTest(unittest.TestCase):
         self.assertEqual("new_display_name", get_param(mocker, "display_name"))
         self.assertTrue(get_param(mocker, "unique_display_name"))
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test34_update_clear_invalid(self, mocker):
+        """Should pass folder decoupling params """
+        mocker.return_value = MOCK_RESPONSE
+        api.update(API_TEST_ID, clear_invalid=True)
+        self.assertTrue(get_param(mocker, "clear_invalid"))
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     @unittest.skip("For this test to work, 'Auto-create folders' should be enabled in the Upload Settings, " +
